@@ -8,6 +8,16 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+__all__ = [
+    "AnalysisData",
+    "fetch_ap_info",
+    "load_ap_info_from_single_file",
+    "SampleCollection",
+    "cache_ap_info",
+    "auth",
+    "authw",
+]
+
 from .analysis_data import AnalysisData
 from .ap_info import (
     SampleCollection,
@@ -15,11 +25,4 @@ from .ap_info import (
     fetch_ap_info,
     load_ap_info_from_single_file,
 )
-
-__all__ = [
-    "AnalysisData",
-    "fetch_ap_info",
-    "load_ap_info_from_single_file",
-    "SampleCollection",
-    "cache_ap_info",
-]
+from .eos import auth, authw
