@@ -14,13 +14,16 @@
 import logging
 import os
 import sys
+import tempfile
 
 import click
 import click_log
+import requests
 
 from .analysis_data import AnalysisData
 from .ap_info import cache_ap_info, load_ap_info
-from .rich_console import console
+from .authentication import get_auth_headers, logout
+from .rich_console import console, error_console
 
 logger = logging.getLogger("apd")
 click_log.basic_config(logger)
@@ -29,7 +32,7 @@ click_log.basic_config(logger)
 def exception_handler(exception_type, exception, _):
     # All your trace are belong to us!
     # your format
-    print(f"{exception_type.__name__}: {exception}")
+    error_console.print(f"{exception_type.__name__}: {exception}")
 
 
 sys.excepthook = exception_handler
@@ -54,6 +57,28 @@ def setup_cache(cache_directory, working_group, analysis, ap_date=None):
         cache_ap_info(cache_directory, working_group, analysis, ap_date=ap_date)
 
 
+@click.command()
+def cmd_login():
+    """Login to the Analysis Productions endpoint"""
+    if "CI_JOB_JWT_V2" in os.environ and "LBAP_TOKENS_FILE" not in os.environ:
+        _, token_file = tempfile.mkstemp(prefix="apd-", suffix=".json")
+        os.environ["LBAP_TOKENS_FILE"] = token_file
+        print(f"export LBAP_TOKENS_FILE={token_file}")
+    r = requests.get(
+        "https://lbap.app.cern.ch/user/",
+        **get_auth_headers(),
+        timeout=10,
+    )
+    r.raise_for_status()
+    console.print(f"Login successful as {r.json()['username']}")
+
+
+@click.command()
+def cmd_logout():
+    """Login to the Analysis Productions endpoint"""
+    logout()
+
+
 @click.command()
 @click.argument("cache_directory")
 @click.argument("working_group")
