@@ -11,5 +11,5 @@
 
 from rich.console import Console
 
-console = Console()
+console = Console(stderr=True)
 error_console = Console(stderr=True, style="bold red")
